@@ -1,8 +1,7 @@
 .is_CRAN_check <-
     function()
 {
-    opt <- getOption("BIOCMANAGER_CRANCHECK_BEHAVIOR", TRUE)
-    opt && any(grepl("_CRAN_", names(Sys.getenv())))
+    !interactive() && ("CheckExEnv" %in% search())
 }
 
 .getAnswer <- function(msg, allowed)
@@ -26,15 +25,20 @@
 .url_exists <-
     function(url)
 {
-    identical(length(.inet_readChar(url, 1L)), 1L)
+    identical(nchar(.inet_readChar(url, 1L)), 1L)
 }
 
 .msg <-
-    function(fmt, ..., width=getOption("width"))
+    function(fmt, ..., width=getOption("width"), wrap. = TRUE)
     ## Use this helper to format all error / warning / message text
 {
-    txt <- strwrap(sprintf(fmt, ...), width=width, exdent=2)
-    paste(txt, collapse="\n")
+    txt <- sprintf(fmt, ...)
+    if (wrap.) {
+        txt <- strwrap(sprintf(fmt, ...), width=width, exdent=2)
+        paste(txt, collapse="\n")
+    } else {
+        txt
+    }
 }
 
 .message <-
